.onLoad <- function(lib,pkg){
library.dynam("steepness",pkg,lib)
}
